# PyLods
Pylods, is a python library for object deserialization and serialization. Pylods provides tools to allow automatic recursive serialization of class instances and implementation of customizes rs and deserializers similar to JacksonJson for java. It currently supports JSON and Msgpack. Check out the project on Github

## Features
-object serializer
-decorators to facilitate:
--type annotation
--assigning order to object properties
--skipping properties
--renaming properties
-creating customer serializers and deserializers based on class type
-create modules and registering modules
-Event Based deserialization (SAX loke) making is suitable for big data
-Easy to extend to new serialization formats

